@@ -394,11 +394,14 @@ var PlacesOrganizer = {
       restorePopup.removeChild(restorePopup.firstChild);
 
     // get list of files
+    var localizedFilename = PlacesUtils.getString("bookmarksArchiveFilename");
+    var localizedFilenamePrefix = localizedFilename.substr(0, localizedFilename.indexOf("-"));
     var fileList = [];
     var files = this.bookmarksBackupDir.directoryEntries;
     while (files.hasMoreElements()) {
       var f = files.getNext().QueryInterface(Ci.nsIFile);
-      if (!f.isHidden() && f.leafName.match(/^bookmarks-.+json$/))
+      var rx = new RegExp("^(bookmarks|" + localizedFilenamePrefix + ")-.+\.json");
+      if (!f.isHidden() && f.leafName.match(rx))
         fileList.push(f);
     }
 
@@ -414,8 +417,8 @@ var PlacesOrganizer = {
       var m = restorePopup.insertBefore
         (document.createElement("menuitem"),
          document.getElementById("restoreFromFile"));
-      var dateStr = fileList[i].leafName.replace("bookmarks-", "").
-        replace(/\.json$/, "");
+      var rx = new RegExp("^(bookmarks|" + localizedFilenamePrefix + ")-");
+      var dateStr = fileList[i].leafName.replace(rx, "").replace(/\.json$/, "");
       if (!dateStr.length)
         dateStr = fileList[i].leafName;
       m.setAttribute("label", dateStr);
@@ -708,9 +711,9 @@ var PlacesOrganizer = {
     // If the advanced query builder is showing, use that.
     var options = this.getCurrentOptions();
 
-//@line 736 "/builds/tinderbox/Fx-Mozilla1.9-Release/Linux_2.6.18-53.1.13.el5_Depend/mozilla/browser/components/places/content/places.js"
+//@line 739 "/builds/tinderbox/Fx-Mozilla1.9-Release/Linux_2.6.18-53.1.13.el5_Depend/mozilla/browser/components/places/content/places.js"
     var queries = this.getCurrentQueries();
-//@line 738 "/builds/tinderbox/Fx-Mozilla1.9-Release/Linux_2.6.18-53.1.13.el5_Depend/mozilla/browser/components/places/content/places.js"
+//@line 741 "/builds/tinderbox/Fx-Mozilla1.9-Release/Linux_2.6.18-53.1.13.el5_Depend/mozilla/browser/components/places/content/places.js"
 
     var placeSpec = PlacesUtils.history.queriesToQueryString(queries,
                                                              queries.length,
@@ -910,7 +913,7 @@ var PlacesSearchBox = {
     var searchModifiers = document.getElementById("searchModifiers");
     searchModifiers.hidden = false;
 
-//@line 942 "/builds/tinderbox/Fx-Mozilla1.9-Release/Linux_2.6.18-53.1.13.el5_Depend/mozilla/browser/components/places/content/places.js"
+//@line 945 "/builds/tinderbox/Fx-Mozilla1.9-Release/Linux_2.6.18-53.1.13.el5_Depend/mozilla/browser/components/places/content/places.js"
   },
 
   hideSearchUI: function PSB_hideSearchUI() {
@@ -927,7 +930,7 @@ var PlacesQueryBuilder = {
   queries: [],
   queryOptions: null,
 
-//@line 1421 "/builds/tinderbox/Fx-Mozilla1.9-Release/Linux_2.6.18-53.1.13.el5_Depend/mozilla/browser/components/places/content/places.js"
+//@line 1424 "/builds/tinderbox/Fx-Mozilla1.9-Release/Linux_2.6.18-53.1.13.el5_Depend/mozilla/browser/components/places/content/places.js"
 
   onScopeSelected: function PQB_onScopeSelected(aButton) {
     var id = aButton.getAttribute("id");
